<?php
/**
 * @package   Invoicing
 * @copyright Copyright (c)2015 - 2020 Juloa
 * @license   GNU General Public License version 3, or later
 */

namespace Juloa\Invoicing\Admin\Toolbar;

use \JText;
use JToolbarHelper;

defined('_JEXEC') or die;

class Toolbar extends \FOF30\Toolbar\Toolbar
{
	public function renderSubmenu()
	{
		$user = \JFactory::getUser();
        if(version_compare(JVERSION, '3.0', 'ge')) {
			$views = array();
			$views[] = 'cpanel';
			if($user->authorise('invoicing.accesssetup','com_invoicing')) {
				$views['COM_INVOICING_MAINMENU_SETUP'] = array();
				if($user->authorise('invoicing.accesscurrency','com_invoicing')) {
					$views['COM_INVOICING_MAINMENU_SETUP'][] = 'currencies';
				}
				if($user->authorise('invoicing.accesstax','com_invoicing')) {
					$views['COM_INVOICING_MAINMENU_SETUP'][] = 'taxes';
				}
				if($user->authorise('invoicing.accessemail','com_invoicing')) {
					$views['COM_INVOICING_MAINMENU_SETUP'][] = 'emails';
				}
				if($user->authorise('invoicing.accesstemplate','com_invoicing')) {
					$views['COM_INVOICING_MAINMENU_SETUP'][] = 'templates';
				}
			}
			if($user->authorise('invoicing.accessproductreference','com_invoicing')) {
				$views[] = 'references';
			}
			if($user->authorise('invoicing.accessvendor','com_invoicing')) {
				$views[] = 'vendors';
			}
			if($user->authorise('invoicing.accessclient','com_invoicing')) {
				$views[] = 'users';
			}
			if($user->authorise('invoicing.accesscoupon','com_invoicing')) {
				$views[] = 'coupons';
			}
			if($user->authorise('invoicing.accessquote','com_invoicing')) {
				$views[] = 'quotes';
			}
			if($user->authorise('invoicing.accessinvoice','com_invoicing')) {
				$views[] = 'invoices';
			}
			if($user->authorise('invoicing.accesslog','com_invoicing')) {
				$views[] = 'log';
			}
        } else {
			$views = array();
			$views[] = 'cpanel';
			if($user->authorise('invoicing.accesscurrency','com_invoicing')) {
				$views[] = 'currencies';
			}
			if($user->authorise('invoicing.accesstax','com_invoicing')) {
				$views[] = 'taxes';
			}
			if($user->authorise('invoicing.accessemail','com_invoicing')) {
				$views[] = 'emails';
			}
			if($user->authorise('invoicing.accesstemplate','com_invoicing')) {
				$views[] = 'templates';
			}
			if($user->authorise('invoicing.accessproductreference','com_invoicing')) {
				$views[] = 'references';
			}
			if($user->authorise('invoicing.accessvendor','com_invoicing')) {
				$views[] = 'vendors';
			}
			if($user->authorise('invoicing.accessclient','com_invoicing')) {
				$views[] = 'users';
			}
			if($user->authorise('invoicing.accesscoupon','com_invoicing')) {
				$views[] = 'coupons';
			}
			if($user->authorise('invoicing.accessquote','com_invoicing')) {
				$views[] = 'quotes';
			}
			if($user->authorise('invoicing.accessinvoice','com_invoicing')) {
				$views[] = 'invoices';
			}
			if($user->authorise('invoicing.accesslog','com_invoicing')) {
				$views[] = 'log';
			}
        }
		
		foreach($views as $label => $view) {
			if(!is_array($view)) {
				$this->addSubmenuLink($view);
			} else {
				$label = \JText::_($label);
				$this->appendLink($label, '', false);
				foreach($view as $v) {
					$this->addSubmenuLink($v, $label);
				}
			}
		}
		
		//parent::renderSubmenu();
		if($user->authorise('invoicing.accesspaymentprocessor','com_invoicing')) {
          if(version_compare(JVERSION, '1.6', 'ge')) {
               $this->appendLink(\JText::_('COM_INVOICING_TITLE_PROCESSORS'), 'index.php?option=com_plugins&filter_folder=invoicingpayment', false);
            // $this->appendLink(\JText::_('COM_INVOICING_TITLE_INTEGRATORS'), 'index.php?option=com_plugins&filter_folder=invoicinggenerator', false);
          } else {
          	   $this->appendLink(\JText::_('COM_INVOICING_TITLE_PROCESSORS'), 'index.php?option=com_plugins&filter_type=invoicingpayment', false);
            // $this->appendLink(\JText::_('COM_INVOICING_TITLE_INTEGRATORS'), 'index.php?option=com_plugins&filter_type=invoicinggenerator', false);
		  }
		}
	}
	
	private function addSubmenuLink($view, $parent = null)
	{
		static $activeView = null;
		$input = \JFactory::getApplication()->input;
		if(empty($activeView)) {
			$activeView = $input->getCmd('view','cpanel');
		}
	
		if ($activeView == 'cpanels')
		{
			$activeView = 'cpanel';
		}
	
		$option = $this->container->componentName;

		$key = strtoupper($option).'_TITLE_'.strtoupper($view);
		if(strtoupper(\JText::_($key)) == $key) {
			$altview = $view;
			$key2 = strtoupper($option).'_TITLE_'.strtoupper($altview);
			if(strtoupper(\JText::_($key2)) == $key2) {
				$name = ucfirst($view);
			} else {
				$name = \JText::_($key2);
			}
		} else {
			$name = \JText::_($key);
		}
	
		$link = 'index.php?option='.$option.'&view='.$view;
	
		$active = $view == $activeView;
	
		$this->appendLink($name, $link, $active, null, $parent);
	}
	
	public function onVendorsBrowse()
	{
		$input = \JFactory::getApplication()->input;
		// Set toolbar title
		$option = $input->getCmd('option','com_invoicing');
		$subtitle_key = strtoupper($option.'_TITLE_'.$input->getCmd('view','cpanel'));
		$content = \JText::_( strtoupper($option)).' &ndash; <small>'.\JText::_($subtitle_key).'</small>';
		$content = strip_tags(preg_replace("/&#?[a-z0-9]{2,8};/i","",$content));
		//strip tags removes <small> preg_replace removes "&ndash;"
		JToolBarHelper::title($content, str_replace('com_', '', $option));

		
		// Add toolbar buttons
		if($this->perms->create) {
			if(version_compare(JVERSION, '3.0', 'ge')) {
				JToolBarHelper::addNew();
			} else {
				JToolBarHelper::addNewX();
			}
		}
		if($this->perms->edit) {
			if(version_compare(JVERSION, '3.0', 'ge')) {
				JToolBarHelper::editList();
			} else {
				JToolBarHelper::editListX();
			}
		}
		if($this->perms->create || $this->perms->edit) {
			JToolBarHelper::divider();
		}

		if($this->perms->delete) {
			$msg = \JText::_($input->getCmd('option','com_invoicing').'_CONFIRM_DELETE');
			JToolBarHelper::deleteList($msg);
		}
		JToolBarHelper::preferences('com_invoicing', 550, 875);
		$label = 'JTOOLBAR_HELP';
		$this->appendLink($label, \JRoute::_('index.php?option=com_invoicing&view=doc'), false);
        $this->renderSubmenu();
	}
	
	public function onTemplatesBrowse()
	{
		$input = \JFactory::getApplication()->input;
		// Set toolbar title
		$option = $input->getCmd('option','com_invoicing');
		$subtitle_key = strtoupper($option.'_TITLE_'.$input->getCmd('view','cpanel'));
		$content = \JText::_( strtoupper($option)).' &ndash; <small>'.\JText::_($subtitle_key).'</small>';
		$content = strip_tags(preg_replace("/&#?[a-z0-9]{2,8};/i","",$content));
		//strip tags removes <small> preg_replace removes "&ndash;"
		JToolBarHelper::title($content, str_replace('com_', '', $option));

	
		// Add toolbar buttons
		/* 		if($this->perms->create) {
		if(version_compare(JVERSION, '3.0', 'ge')) {
		JToolBarHelper::addNew();
		} else {
		JToolBarHelper::addNewX();
		}
		} */
	
		if($this->perms->edit) {
			if(version_compare(JVERSION, '3.0', 'ge')) {
				JToolBarHelper::editList();
			} else {
			JToolBarHelper::editListX();
			}
		}
		if($this->perms->create || $this->perms->edit) {
			JToolBarHelper::divider();
		}
	
		JToolBarHelper::preferences('com_invoicing', 550, 875);
		$label = 'JTOOLBAR_HELP';
		$this->appendLink($label, \JRoute::_('index.php?option=com_invoicing&view=doc'), false);
        $this->renderSubmenu();
	}
	
	public function onTemplatesEdit()
	{
		$input = \JFactory::getApplication()->input;
		// Set toolbar title
		$option = $input->getCmd('option','com_invoicing');
		$subtitle_key = strtoupper($option.'_TITLE_'.$input->getCmd('view','cpanel'));
		$content = \JText::_( strtoupper($option)).' &ndash; <small>'.\JText::_($subtitle_key).'</small>';
		$content = strip_tags(preg_replace("/&#?[a-z0-9]{2,8};/i","",$content));
		//strip tags removes <small> preg_replace removes "&ndash;"
		JToolBarHelper::title($content, str_replace('com_', '', $option));

	
		if($this->perms->edit) {
					JToolBarHelper::apply();
					JToolBarHelper::save();
					JToolBarHelper::cancel();
		}
		JToolBarHelper::preferences('com_invoicing', 550, 875);
		$label = 'JTOOLBAR_HELP';
		$this->appendLink($label, \JRoute::_('index.php?option=com_invoicing&view=doc'), false);
        		$this->renderSubmenu();
	}
	
	public function onEmailsBrowse()
	{
		$input = \JFactory::getApplication()->input;
		// Set toolbar title
		$option = $input->getCmd('option','com_invoicing');
		$subtitle_key = strtoupper($option.'_TITLE_'.$input->getCmd('view','cpanel'));
		$content = \JText::_( strtoupper($option)).' &ndash; <small>'.\JText::_($subtitle_key).'</small>';
		$content = strip_tags(preg_replace("/&#?[a-z0-9]{2,8};/i","",$content));
		//strip tags removes <small> preg_replace removes "&ndash;"
		JToolBarHelper::title($content, str_replace('com_', '', $option));

		
		// Add toolbar buttons
/* 		if($this->perms->create) {
			if(version_compare(JVERSION, '3.0', 'ge')) {
				JToolBarHelper::addNew();
			} else {
				JToolBarHelper::addNewX();
			}
		} */
		
		if($this->perms->edit) {
			if(version_compare(JVERSION, '3.0', 'ge')) {
				JToolBarHelper::editList();
			} else {
				JToolBarHelper::editListX();
			}
		}
		if($this->perms->create || $this->perms->edit) {
			JToolBarHelper::divider();
		}

		JToolBarHelper::preferences('com_invoicing', 550, 875);
		$label = 'JTOOLBAR_HELP';
		$this->appendLink($label, \JRoute::_('index.php?option=com_invoicing&view=doc'), false);
        $this->renderSubmenu();
	}
	
	public function onLogsEdit()
	{
		$input = \JFactory::getApplication()->input;
		// Set toolbar title
		$option = $input->getCmd('option','com_invoicing');
		$subtitle_key = strtoupper($option.'_TITLE_'.$input->getCmd('view','cpanel'));
		$content = \JText::_( strtoupper($option)).' &ndash; <small>'.\JText::_($subtitle_key).'</small>';
		$content = strip_tags(preg_replace("/&#?[a-z0-9]{2,8};/i","",$content));
		//strip tags removes <small> preg_replace removes "&ndash;"
		JToolBarHelper::title($content, str_replace('com_', '', $option));
		
		JToolBarHelper::preferences('com_invoicing', 550, 875);
		$label = 'JTOOLBAR_HELP';
		$this->appendLink($label, \JRoute::_('index.php?option=com_invoicing&view=doc'), false);
        $this->renderSubmenu();
	}

	public function onEmailsEdit()
	{
		$input = \JFactory::getApplication()->input;
		// Set toolbar title
		$option = $input->getCmd('option','com_invoicing');
		$subtitle_key = strtoupper($option.'_TITLE_'.$input->getCmd('view','cpanel'));
		$content = \JText::_( strtoupper($option)).' &ndash; <small>'.\JText::_($subtitle_key).'</small>';
		$content = strip_tags(preg_replace("/&#?[a-z0-9]{2,8};/i","",$content));
		//strip tags removes <small> preg_replace removes "&ndash;"
		JToolBarHelper::title($content, str_replace('com_', '', $option));

		
		if($this->perms->edit) {
				JToolBarHelper::apply();
				JToolBarHelper::save();
				JToolBarHelper::cancel();
		}
		JToolBarHelper::preferences('com_invoicing', 550, 875);
		$label = 'JTOOLBAR_HELP';
		$this->appendLink($label, \JRoute::_('index.php?option=com_invoicing&view=doc'), false);
        $this->renderSubmenu();
	}
	
	public function onInvoicesMail()
	{
		$input = \JFactory::getApplication()->input;
		// Set toolbar title
		$option = $input->getCmd('option','com_invoicing');
		$subtitle_key = strtoupper($option.'_TITLE_'.$input->getCmd('view','cpanel'));
		$content = \JText::_( strtoupper($option)).' &ndash; <small>'.\JText::_($subtitle_key).'</small>';
		$content = strip_tags(preg_replace("/&#?[a-z0-9]{2,8};/i","",$content));
		//strip tags removes <small> preg_replace removes "&ndash;"
		JToolBarHelper::title($content, str_replace('com_', '', $option));

		JToolBarHelper::preferences('com_invoicing', 550, 875);
		$this->renderSubmenu();
	}
	
	
	
	public function onUsersBrowse()
	{
		$input = \JFactory::getApplication()->input;
		// Set toolbar title
		$option = $input->getCmd('option','com_invoicing');
		$subtitle_key = strtoupper($option.'_TITLE_'.$input->getCmd('view','cpanel'));
		$content = \JText::_( strtoupper($option)).' &ndash; <small>'.\JText::_($subtitle_key).'</small>';
		$content = strip_tags(preg_replace("/&#?[a-z0-9]{2,8};/i","",$content));
		//strip tags removes <small> preg_replace removes "&ndash;"
		JToolBarHelper::title($content, str_replace('com_', '', $option));

		
		// Add toolbar buttons
		if($this->perms->create) {
			if(version_compare(JVERSION, '3.0', 'ge')) {
				JToolBarHelper::addNew();
			} else {
				JToolBarHelper::addNewX();
			}
		}
		if($this->perms->edit) {
			if(version_compare(JVERSION, '3.0', 'ge')) {
				JToolBarHelper::editList();
			} else {
				JToolBarHelper::editListX();
			}
		}
		if($this->perms->create || $this->perms->edit) {
			JToolBarHelper::divider();
		}

		if($this->perms->delete) {
			$msg = \JText::_($input->getCmd('option','com_invoicing').'_CONFIRM_DELETE');
			JToolBarHelper::deleteList($msg);
		}
		JToolBarHelper::preferences('com_invoicing', 550, 875);
		$label = 'JTOOLBAR_HELP';
		$this->appendLink($label, \JRoute::_('index.php?option=com_invoicing&view=doc'), false);
        $this->renderSubmenu();
	}
	
		public function onInvoicesBrowse()
	{
		$input = \JFactory::getApplication()->input;
		// Set toolbar title
		$option = $input->getCmd('option','com_invoicing');
		$subtitle_key = strtoupper($option.'_TITLE_'.$input->getCmd('view','cpanel'));
		$content = \JText::_( strtoupper($option)).' &ndash; <small>'.\JText::_($subtitle_key).'</small>';
		$content = strip_tags(preg_replace("/&#?[a-z0-9]{2,8};/i","",$content));
		//strip tags removes <small> preg_replace removes "&ndash;"
		JToolBarHelper::title($content, str_replace('com_', '', $option));

		// Add toolbar buttons
		if($this->perms->create) {
			if(version_compare(JVERSION, '3.0', 'ge')) {
				JToolBarHelper::addNew();
			} else {
				JToolBarHelper::addNewX();
			}
		}
		if($this->perms->edit) {
			if(version_compare(JVERSION, '3.0', 'ge')) {
				JToolBarHelper::editList();
			} else {
				JToolBarHelper::editListX();
			}
		}
		if($this->perms->create || $this->perms->edit) {
			JToolBarHelper::divider();
		}

		if($this->perms->delete) {
			$msg = \JText::_($input->getCmd('option','com_invoicing').'_CONFIRM_DELETE');
			JToolBarHelper::deleteList($msg);
		}
		JToolBarHelper::preferences('com_invoicing', 550, 875);
		$label = 'JTOOLBAR_HELP';
		$this->appendLink($label, \JRoute::_('index.php?option=com_invoicing&view=doc'), false);
        $this->renderSubmenu();
	}
	
    public function onQuotesBrowse()
	{
		$input = \JFactory::getApplication()->input;
		// Set toolbar title
		$option = $input->getCmd('option','com_invoicing');
		$subtitle_key = strtoupper($option.'_TITLE_'.$input->getCmd('view','cpanel'));
		$content = \JText::_( strtoupper($option)).' &ndash; <small>'.\JText::_($subtitle_key).'</small>';
		$content = strip_tags(preg_replace("/&#?[a-z0-9]{2,8};/i","",$content));
		//strip tags removes <small> preg_replace removes "&ndash;"
		JToolBarHelper::title($content, str_replace('com_', '', $option));

		
		// Add toolbar buttons
		if($this->perms->create) {
			if(version_compare(JVERSION, '3.0', 'ge')) {
				JToolBarHelper::addNew();
			} else {
				JToolBarHelper::addNewX();
			}
		}
		if($this->perms->edit) {
			if(version_compare(JVERSION, '3.0', 'ge')) {
				JToolBarHelper::editList();
			} else {
				JToolBarHelper::editListX();
			}
		}
		if($this->perms->create || $this->perms->edit) {
			JToolBarHelper::divider();
		}

		if($this->perms->delete) {
			$msg = \JText::_($input->getCmd('option','com_invoicing').'_CONFIRM_DELETE');
			JToolBarHelper::deleteList($msg);
		}
        
        JToolBarHelper::custom('toInvoice', 'stats','',\JText::_('COM_INVOICING_TO_INVOICE'));
		
				JToolBarHelper::preferences('com_invoicing', 550, 875);
				$label = 'JTOOLBAR_HELP';
				$this->appendLink($label, \JRoute::_('index.php?option=com_invoicing&view=doc'), false);
        $this->renderSubmenu();
	}
    
	public function onProcessorsBrowse()
	{
		$input = \JFactory::getApplication()->input;
		// Set toolbar title
		$option = $input->getCmd('option','com_invoicing');
		$subtitle_key = strtoupper($option.'_TITLE_'.$input->getCmd('view','cpanel'));
		$content = \JText::_( strtoupper($option)).' &ndash; <small>'.\JText::_($subtitle_key).'</small>';
		$content = strip_tags(preg_replace("/&#?[a-z0-9]{2,8};/i","",$content));
		//strip tags removes <small> preg_replace removes "&ndash;"
		JToolBarHelper::title($content, str_replace('com_', '', $option));

	
		// Add toolbar buttons
		if($this->perms->edit) {
			if(version_compare(JVERSION, '3.0', 'ge')) {
				JToolBarHelper::editList();
			} else {
				JToolBarHelper::editListX();
			}
		}
		$this->renderSubmenu();
	}
	
	public function onPluginsBrowse($plugin_type) {
		$input = \JFactory::getApplication()->input;
		// Set toolbar title
		$option = $input->getCmd('option','com_invoicing');
		if ($plugin_type == "invoicingpayment") {
			$subtitle_key = 'COM_INVOICING_TITLE_PROCESSORS';
		} else {
			$subtitle_key = 'COM_INVOICING_TITLE_INTEGRATORS';
		}
		$content = \JText::_( strtoupper($option)).' &ndash; <small>'.\JText::_($subtitle_key).'</small>';
		$content = strip_tags(preg_replace("/&#?[a-z0-9]{2,8};/i","",$content));
		//strip tags removes <small> preg_replace removes "&ndash;"
		JToolBarHelper::title($content, str_replace('com_', '', $option));

		JToolBarHelper::preferences('com_invoicing', 550, 875);
		$this->renderSubmenu();
	}
	
	public function onBrowse()
	{
		parent::onBrowse();
		JToolBarHelper::preferences('com_invoicing', 550, 875);
		$label = 'JTOOLBAR_HELP';
		$this->appendLink($label, \JRoute::_('index.php?option=com_invoicing&view=doc'), false);
    }
	
	public function onCpanelsBrowse(){
		$option = FOFInput::getCmd('option','com_invoicing',$this->input);
		$content = \JText::_( strtoupper($option));
		$content = strip_tags(preg_replace("/&#?[a-z0-9]{2,8};/i","",$content));
		//strip tags removes <small> preg_replace removes "&ndash;"
		JToolBarHelper::title($content, str_replace('com_', '', $option));

		
		JToolBarHelper::preferences('com_invoicing', 550, 875);
		$label = 'JTOOLBAR_HELP';
		$this->appendLink($label, \JRoute::_('index.php?option=com_invoicing&view=doc'), false);
        $this->renderSubmenu();
	}
	
	public function onCouponsBrowse()
	{
		$input = \JFactory::getApplication()->input;
		// Set toolbar title
		$option = $input->getCmd('option','com_invoicing');
		$subtitle_key = strtoupper($option.'_TITLE_'.$input->getCmd('view','cpanel'));
		$content = \JText::_( strtoupper($option)).' &ndash; <small>'.\JText::_($subtitle_key).'</small>';
		$content = strip_tags(preg_replace("/&#?[a-z0-9]{2,8};/i","",$content));
		//strip tags removes <small> preg_replace removes "&ndash;"
		JToolBarHelper::title($content, str_replace('com_', '', $option));

		// Add toolbar buttons
		if($this->perms->create) {
			if(version_compare(JVERSION, '3.0', 'ge')) {
				JToolBarHelper::addNew();
			} else {
				JToolBarHelper::addNewX();
			}
		}
		if($this->perms->edit) {
			if(version_compare(JVERSION, '3.0', 'ge')) {
				JToolBarHelper::editList();
			} else {
				JToolBarHelper::editListX();
			}
			JToolBarHelper::publish();
			JToolBarHelper::unpublish();
		}
		if($this->perms->create || $this->perms->edit) {
			JToolBarHelper::divider();
		}

		if($this->perms->delete) {
			$msg = \JText::_($input->getCmd('option','com_invoicing').'_CONFIRM_DELETE');
			JToolBarHelper::deleteList($msg);
		}
		
		JToolBarHelper::preferences('com_invoicing', 550, 875);
		$label = 'JTOOLBAR_HELP';
		$this->appendLink($label, \JRoute::_('index.php?option=com_invoicing&view=doc'), false);
        $this->renderSubmenu();
	}
	
	public function onCurrenciesBrowse()
	{
		$input = \JFactory::getApplication()->input;
		// Set toolbar title
		$option = $input->getCmd('option','com_invoicing');
		$subtitle_key = strtoupper($option.'_TITLE_'.$input->getCmd('view','cpanel'));
		$content = \JText::_( strtoupper($option)).' &ndash; <small>'.\JText::_($subtitle_key).'</small>';
		$content = strip_tags(preg_replace("/&#?[a-z0-9]{2,8};/i","",$content));
		//strip tags removes <small> preg_replace removes "&ndash;"
		JToolBarHelper::title($content, str_replace('com_', '', $option));

		// Add toolbar buttons
		if($this->perms->create) {
			if(version_compare(JVERSION, '3.0', 'ge')) {
				JToolBarHelper::addNew();
			} else {
				JToolBarHelper::addNewX();
			}
		}
		if($this->perms->edit) {
			if(version_compare(JVERSION, '3.0', 'ge')) {
				JToolBarHelper::editList();
			} else {
				JToolBarHelper::editListX();
			}
			JToolBarHelper::publish();
			JToolBarHelper::unpublish();
		}
		if($this->perms->create || $this->perms->edit) {
			JToolBarHelper::divider();
		}

		if($this->perms->delete) {
			$msg = \JText::_($input->getCmd('option','com_invoicing').'_CONFIRM_DELETE');
			JToolBarHelper::deleteList($msg);
		}
		
		JToolBarHelper::preferences('com_invoicing', 550, 875);
		$label = 'JTOOLBAR_HELP';
		$this->appendLink($label, \JRoute::_('index.php?option=com_invoicing&view=doc'), false);
        $this->renderSubmenu();
	}
	
	public function onReferencesBrowse()
	{
		$input = \JFactory::getApplication()->input;
		// Set toolbar title
		$option = $input->getCmd('option','com_invoicing');
		$subtitle_key = strtoupper($option.'_TITLE_'.$input->getCmd('view','cpanel'));
		$content = \JText::_( strtoupper($option)).' &ndash; <small>'.\JText::_($subtitle_key).'</small>';
		$content = strip_tags(preg_replace("/&#?[a-z0-9]{2,8};/i","",$content));
		//strip tags removes <small> preg_replace removes "&ndash;"
		JToolBarHelper::title($content, str_replace('com_', '', $option));

		// Add toolbar buttons
		if($this->perms->create) {
			if(version_compare(JVERSION, '3.0', 'ge')) {
				JToolBarHelper::addNew();
			} else {
				JToolBarHelper::addNewX();
			}
		}
		if($this->perms->edit) {
			if(version_compare(JVERSION, '3.0', 'ge')) {
				JToolBarHelper::editList();
			} else {
				JToolBarHelper::editListX();
			}
			JToolBarHelper::publish();
			JToolBarHelper::unpublish();
		}
		if($this->perms->create || $this->perms->edit) {
			JToolBarHelper::divider();
		}

		if($this->perms->delete) {
			$msg = \JText::_($input->getCmd('option','com_invoicing').'_CONFIRM_DELETE');
			JToolBarHelper::deleteList($msg);
		}
		
		JToolBarHelper::preferences('com_invoicing', 550, 875);
		$label = 'JTOOLBAR_HELP';
		$this->appendLink($label, \JRoute::_('index.php?option=com_invoicing&view=doc'), false);
        $this->renderSubmenu();
	}
	
	public function onTaxesBrowse()
	{
		$input = \JFactory::getApplication()->input;
		// Set toolbar title
		$option = $input->getCmd('option','com_invoicing');
		$subtitle_key = strtoupper($option.'_TITLE_'.$input->getCmd('view','cpanel'));
		$content = \JText::_( strtoupper($option)).' &ndash; <small>'.\JText::_($subtitle_key).'</small>';
		$content = strip_tags(preg_replace("/&#?[a-z0-9]{2,8};/i","",$content));
		//strip tags removes <small> preg_replace removes "&ndash;"
		JToolBarHelper::title($content, str_replace('com_', '', $option));

		// Add toolbar buttons
		if($this->perms->create) {
			if(version_compare(JVERSION, '3.0', 'ge')) {
				JToolBarHelper::addNew();
			} else {
				JToolBarHelper::addNewX();
			}
		}
		if($this->perms->edit) {
			if(version_compare(JVERSION, '3.0', 'ge')) {
				JToolBarHelper::editList();
			} else {
				JToolBarHelper::editListX();
			}
			JToolBarHelper::publish();
			JToolBarHelper::unpublish();
		}
		if($this->perms->create || $this->perms->edit) {
			JToolBarHelper::divider();
		}

		if($this->perms->delete) {
			$msg = \JText::_($input->getCmd('option','com_invoicing').'_CONFIRM_DELETE');
			JToolBarHelper::deleteList($msg);
		}
		
		JToolBarHelper::preferences('com_invoicing', 550, 875);
		$label = 'JTOOLBAR_HELP';
		$this->appendLink($label, \JRoute::_('index.php?option=com_invoicing&view=doc'), false);
        $this->renderSubmenu();
	}
    
	// Do not add Help in Edit because onedit call onAdd    
    public function onAdd()
	{
		parent::onAdd();
		$label = 'JTOOLBAR_HELP';
		$this->appendLink($label, \JRoute::_('index.php?option=com_invoicing&view=doc'), false);
    }
}