<?php
/**
 * @package		invoicing
 * @copyright	Copyright (c)2010-2014 Nicholas K. Dionysopoulos / AkeebaBackup.com / Juloa
 * @license		GNU GPLv3 <http://www.gnu.org/licenses/gpl.html> or later
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die( 'Restricted access' );

require_once(JPATH_ADMINISTRATOR.'/components/com_invoicing/assets/paymentplugin.php');
require_once(JPATH_ADMINISTRATOR.'/components/com_invoicing/helpers/format.php');
require_once(JPATH_ADMINISTRATOR.'/components/com_invoicing/helpers/log.php');

class plgInvoicingpaymentStripe extends InvoicingAbstractPaymentPlugin
{
	public function __construct(&$subject, $config = array())
	{
		$config = array_merge($config, array(
			'ppName'		=> 'stripe',
			'ppKey'			=> 'PLG_INVOICINGPAYMENT_STRIPE_TITLE',
			'ppImage'		=> JURI::root().'plugins/invoicingpayment/stripe/stripe/stripe.jpg',
		));

		parent::__construct($subject, $config);

		require_once dirname(__FILE__).'/stripe/lib/Stripe.php';
	}

	/**
	 * Returns the payment form to be submitted by the user's browser. The form must have an ID of
	 * "paymentForm" and a visible submit button.
	 *
	 */
	public function onInvoicingPaymentDisplay($paymentmethod, $data)
	{
		if($paymentmethod != $this->ppName) return false;

		$doc = \JFactory::getDocument();
		$doc->addScriptDeclaration("
			Stripe.setPublishableKey('" . $this->getPublicKey() . "');
			");
		$doc->addScript("https://js.stripe.com/v2/");
		if(version_compare(JVERSION, '3.0', 'ge')) {
			// jQuery
			$doc->addScriptDeclaration("
				jQuery(function($){
					var stripeResponseHandler = function(status, response) {
						$('.control-group').removeClass('error');
						if (response.error) {
							if(response.error.code == 'incorrect_number') {
								$('#control-group-card-number').addClass('error');
								$('#payment-errors').text(\"" . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_INCORRECT_NUMBER') . "\");
							}else if(response.error.code == 'invalid_number') {
								$('#control-group-card-number').addClass('error');
								$('#payment-errors').text(\"" . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_INVALID_NUMBER') . "\");
							}else if(response.error.code == 'invalid_expiry_month') {
								$('#control-group-card-expiry').addClass('error');
								$('#payment-errors').text(\"" . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_INVALID_EXP_MONTH') . "\");
							}else if(response.error.code == 'invalid_expiry_year') {
								$('#control-group-card-expiry').addClass('error');
								$('#payment-errors').text(\"" . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_INVALID_EXP_YEAR') . "\");
							}else if(response.error.code == 'invalid_cvc') {
								$('#control-group-card-cvc').addClass('error');
								$('#payment-errors').text(\"" . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_INVALID_CVC') . "\");
							}else if(response.error.code == 'expired_card') {
								$('#control-group-card-expiry').addClass('error');
								$('#payment-errors').text(\"" . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_EXPIRED_CARD') . "\");
							}else if(response.error.code == 'incorrect_cvc') {
								$('#control-group-card-cvc').addClass('error');
								$('#payment-errors').text(\"" . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_INCORRECT_CVC') . "\");
							}else if(response.error.code == 'card_declined') {
								$('#control-group-card-number').addClass('error');
								$('#payment-errors').text(\"" . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_CARD_DECLINED') . "\");
							}else if(response.error.code == 'missing') {
								$('#payment-errors').text(\"" . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_MISSING') . "\");
							}else if(response.error.code == 'processing_error') {
								$('#payment-errors').text(\"" . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_PROCESSING_ERROR') . "\");
							}else if(status == 401) {
								$('#payment-errors').text(\"" . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_UNAUTHORIZED') . "\");
							}else if(status == 402) {
								$('#payment-errors').text(\"" . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_REQUEST_FAILED') . "\");
							}else if(status == 404) {
								$('#payment-errors').text(\"" . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_NOT_FOUND') . "\");
							}else if(status >= 500) {
								$('#payment-errors').text(\"" . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_SERVER_ERROR') . "\");
							}else {
								$('#payment-errors').text(\"" . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_UNKNOWN_ERROR') . "\");
							}
							$('#payment-errors').show();
							$('#payment-button').removeAttr('disabled');
						} else {
							$('#payment-errors').hide();
							var token = response.id;
							$('#token').val(token);
							$('#payment-form').submit();
						}
					};

					$('#payment-form').submit(function(e){
						var token = $('#token').val();
						if(!!token) {
							return true;
						}else{
							$('#payment-button').attr('disabled', 'disabled');
							Stripe.createToken({
								number:$('#card-number').val(),
								exp_month:$('#card-expiry-month').val(),
								exp_year:$('#card-expiry-year').val(),
								cvc:$('#card-cvc').val()
							}, stripeResponseHandler);
							return false;
						}
					});
				});
			");
		} else {
			// Mootools
			$doc->addScriptDeclaration("\n" . 'window.addEvent(\'domready\', function(){
						function StripeResponseHandler(status, response) {
							$$(\'.control-group\').removeClass(\'error\');
							if (response.error) {
								if(response.error.code == \'incorrect_number\') {
									$(\'control-group-card-number\').addClass(\'error\');
									$(\'payment-errors\').set(\'html\', "' . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_INCORRECT_NUMBER') . '");
								}else if(response.error.code == \'invalid_number\') {
									$(\'control-group-card-number\').addClass(\'error\');
									$(\'payment-errors\').set(\'html\', "' . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_INVALID_NUMBER') . '");
								}else if(response.error.code == \'invalid_expiry_month\') {
									$(\'control-group-card-expiry\').addClass(\'error\');
									$(\'payment-errors\').set(\'html\', "' . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_INVALID_EXP_MONTH') . '");
								}else if(response.error.code == \'invalid_expiry_year\') {
									$(\'control-group-card-expiry\').addClass(\'error\');
									$(\'payment-errors\').set(\'html\', "' . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_INVALID_EXP_YEAR') . '");
								}else if(response.error.code == \'invalid_cvc\') {
									$(\'control-group-card-cvc\').addClass(\'error\');
									$(\'payment-errors\').set(\'html\', "' . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_INVALID_CVC') . '");
								}else if(response.error.code == \'expired_card\') {
									$(\'control-group-card-expiry\').addClass(\'error\');
									$(\'payment-errors\').set(\'html\', "' . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_EXPIRED_CARD') . '");
								}else if(response.error.code == \'incorrect_cvc\') {
									$(\'control-group-card-cvc\').addClass(\'error\');
									$(\'payment-errors\').set(\'html\', "' . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_INCORRECT_CVC') . '");
								}else if(response.error.code == \'card_declined\') {
									$(\'control-group-card-number\').addClass(\'error\');
									$(\'payment-errors\').set(\'html\', "' . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_CARD_DECLINED') . '");
								}else if(response.error.code == \'missing\') {
									$(\'payment-errors\').set(\'html\', "' . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_MISSING') . '");
								}else if(response.error.code == \'processing_error\') {
									$(\'payment-errors\').set(\'html\', "' . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_PROCESSING_ERROR') . '");
								}else if(status == 401) {
									$(\'payment-errors\').set(\'html\', "' . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_UNAUTHORIZED') . '");
								}else if(status == 402) {
									$(\'payment-errors\').set(\'html\', "' . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_REQUEST_FAILED') . '");
								}else if(status == 404) {
									$(\'payment-errors\').set(\'html\', "' . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_NOT_FOUND') . '");
								}else if(status >= 500) {
									$(\'payment-errors\').set(\'html\', "' . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_SERVER_ERROR') . '");
								}else {
									$(\'payment-errors\').set(\'html\', "' . \JText::_('PLG_INVOICINGPAYMENT_STRIPE_FORM_UNKNOWN_ERROR') . '");
								}
								$(\'payment-errors\').setStyle(\'display\',\'\');
								$(\'payment-button\').set(\'disabled\', false);
							} else {
								$(\'payment-errors\').setStyle(\'display\',\'none\');
								var token = response.id;
								$(\'token\').set(\'value\', token);
								$(\'payment-form\').submit();
							}
						}

						$(\'payment-form\').addEvents({
							submit: function(){
								Stripe.createToken({
									number:$(\'card-number\').value,
									exp_month:$(\'card-expiry-month\').value,
									exp_year:$(\'card-expiry-year\').value,
									cvc:$(\'card-cvc\').value
								}, StripeResponseHandler);
								$(\'payment-button\').set(\'disabled\', true);
								return false;
							}
						});
					});' . "\n");
		}

		include_once(JPATH_ROOT.'/administrator/components/com_invoicing/helpers/format.php');
		$callbackUrl = JURI::base().'index.php?option=com_invoicing&view=message&layout=complete';
		$currencyModel = InvoicingModelCurrencies::getInstance('Currencies', 'InvoicingModel');
		$currency = $currencyModel->getItem($data->currency_id);
		$currency_code = $currency->code;
		$user = \JFactory::getUser();
		$data = (object)array(
			'url'			=> $callbackUrl,
			'amount'		=> (int)($data->gross_amount),
			'currency'		=> strtolower($currency_code),
			'description'	=> InvoicingHelperFormat::formatOrderNumber($data),
			'cardholder'	=> $user->name
		);

		@ob_start();
		include dirname(__FILE__).'/stripe/form.php';
		$html = @ob_get_clean();

		return $html;
	}

	public function onInvoicingPaymentNotification($paymentmethod, $data)
	{
		JLoader::import('joomla.utilities.date');

		// Check if we're supposed to handle this
		if($paymentmethod != $this->ppName) return false;
		$isValid = true;

		InvoicingHelperLog::log("Stripe Begin");

		if($isValid) {
			try {
				$apiKey = $this->getPrivateKey();
				Stripe::setApiKey($apiKey);
				$params = array(
					'amount'		=> $data['amount'],
					'currency'		=> $data['currency'],
					'card'			=> $data['token'],
					'description'	=> $data['description']
				);
				$transaction = Stripe_Charge::create($params);
			}catch(Exception $e) {
				$isValid = false;
				InvoicingHelperLog::log('Stripe Failure: '.$e->getMessage());
			}
		}

		// Check that transaction has not been previously processed
		/*if($isValid) {
			if($transaction['id'] == $subscription->processor_key) {
				$isValid = false;
				$data['akeebasubs_failure_reason'] = "I will not processe this transaction twice";
			}
		}*/

		$sandbox = $this->params->get('sandbox');
		if($isValid) {
			if($sandbox == $transaction['livemode']) {
				$isValid = false;
				InvoicingHelperLog::log('Stripe Failure: Transaction done in wrong mode.');
			}
		}

		if($isValid) {
			$id = array_key_exists('sid', $data) ? (int)$data['sid'] : -1;
			$amount = floatval($data['amount']);
			$isGrossAmount = true;
			$currency = strtoupper($data['currency']);
			
			if ($this->checkValidity($id,$amount,$isGrossAmount,$currency) == true) {
				$this->validPayment($id,$paymentmethod);
			} else {
				$isValid = false;
				InvoicingHelperLog::log('Stripe Failure: Check Validity failed');
			}
		}

		// Fraud attempt? Do nothing more!
		if(!$isValid) return false;
	}

	private function getPublicKey()
	{
		$sandbox = $this->params->get('sandbox',0);
		if($sandbox) {
			return trim($this->params->get('sb_public_key',''));
		} else {
			return trim($this->params->get('public_key',''));
		}
	}

	private function getPrivateKey()
	{
		$sandbox = $this->params->get('sandbox',0);
		if($sandbox) {
			return trim($this->params->get('sb_private_key',''));
		} else {
			return trim($this->params->get('private_key',''));
		}
	}

	public function selectMonth()
	{
		$options = array();
		$options[] = JHTML::_('select.option',0,'--');
		for($i = 1; $i <= 12; $i++) {
			$m = sprintf('%02u', $i);
			$options[] = JHTML::_('select.option',$m,$m);
		}

		return JHTML::_('select.genericlist', $options, 'card-expiry-month', 'class="input-small"', 'value', 'text', '', 'card-expiry-month');
	}

	public function selectYear()
	{
		$year = gmdate('Y');

		$options = array();
		$options[] = JHTML::_('select.option',0,'--');
		for($i = 0; $i <= 10; $i++) {
			$y = sprintf('%04u', $i+$year);
			$options[] = JHTML::_('select.option',$y,$y);
		}

		return JHTML::_('select.genericlist', $options, 'card-expiry-year', 'class="input-small"', 'value', 'text', '', 'card-expiry-year');
	}
}